#!/bin/bash
#
# packager                          : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
#
# dernires rvisions       : 01/12/2008
#
#package			: azureus
#homepage			: http://azureus.sourceforge.net/
#source location	: http://heanet.dl.sourceforge.net/sourceforge/azureus/Vuze_4.0.0.4_linux.tar.bz2
#dependency         : java

softnamesrc='Vuze_4.0.0.4_linux'
softname='vuze'
softversion='4.0.0.4'
packageversion='54.1'
arch='i486'

#
# destination du package
#
prefix=/usr

#
# log
#
(

#
# paramtres pour compiler
#
buildir=$(pwd)
srcpkg="$buildir/$softnamesrc.tar.bz2"
src="$buildir/$softname"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://heanet.dl.sourceforge.net/sourceforge/azureus/$softnamesrc.tar.bz2

#
# preparer le rpertoire qui accueillera la compilation
#
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/$prefix/lib
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps/
mkdir -p $dest/usr/src/$softname-$softversion

#
# mettre le slack-desc en place. 
#
cat <<EOF > $dest/install/slack-desc
    |-----handy-ruler------------------------------------------------------|
vuze: vuze - BitTorrent client
vuze:
vuze: Vuze implements the BitTorrent protocol using java 
vuze: language and comes bundled with many invaluable features 
vuze: for both beginners and advanced users.
vuze: 
vuze: 
vuze:
vuze: 
vuze:
vuze: 
EOF

#
# Verifie si package est present
#
if [ -f $softnamesrc.tar.bz2 ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

#
# extraire les sources
#
# tar.gz : tar zxvf $srcpkg
# tar.bz2: tar xjvf $srcpkg
# tgz    : tar xzvf $srcpkg
#
cd $buildir
tar xvjf $srcpkg
cd $src

#
# copie le programme au bon endroit
#
cp -rf $src $dest/usr/lib
cp -v ../swt.jar $dest/usr/lib/$softname/

#
# ajout des fichiers de docs, infos, ...
#
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      GPL.txt TOS.txt README.txt ChangeLog.txt installer.log\
      $dest/usr/doc/$softname-$softversion
	
	rm $dest/usr/lib/$softname/{*.txt,*.log} 
	
#
# faire le fichier .desktop
#
if [ ! -f $dest/usr/share/applications/$softname.desktop ]; then
cat << "EOF" > $dest/usr/share/applications/$softname.desktop
[Desktop Entry]
Name=Vuze
Comment=BitTorrent client
Exec=vuze
Icon=vuze
Categories=Application;Network;
Terminal=false
Type=Application
Encoding=UTF-8
EOF
fi

cat <<EOF > $dest/usr/bin/vuze
#!/bin/sh
exec /usr/lib/vuze/vuze
EOF

chmod 755 $dest/usr/bin/vuze

#
# le package doit tre "freedesktop" compliant
#
rm $dest/usr/lib/$softname/vuze.png
cd $src
cp $softname.png $dest/usr/share/icons/hicolor/48x48/apps/$softname.png

#
# Mettre le zenbuild  sa place
#
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion

#
# fixer les permissions
#
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

#
# fabriquer le zenpackage
#
cd $dest
makepkg -l y -c n $dest.tgz

#
# produire la signature md5 du package
#
cd $buildir
md5sum $package.tgz > $package.md5

#
# fabriquer le fichier dpendance
#
echo -n "directfb,freetype,gcc,libdrm,jre,sdl,xorg-libs,xcb,zlib" > $package.dep

#
# Fabriquer le fichier source
#
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/xap/azureus/source/build-azureus.sh > $package.src
echo $source >$package.src

#
# supprimer source
#
rm -rf $src
rm -rf $dest

#
# log
#
) 2>&1 | tee "$softname-$softversion-build.log"
